@@ -13,7 +13,7 @@ tufte_handout <- function(fig_width = 4,
                           dev = 'pdf',
                           highlight = "default",
                           keep_tex = FALSE,
-                          citation_package = c("natbib", "biblatex"),
+                          citation_package = c("none", "natbib", "biblatex"),
                           includes = NULL,
                           md_extensions = NULL,
                           pandoc_args = NULL) {
